Package: rsimsum
Title: Analysis of Simulation Studies Including Monte Carlo Error
Version: 0.13.1
Authors@R: c(
    person(
        given = "Alessandro", 
        family = "Gasparini", 
        email = "alessandro@ellessenne.xyz", 
        comment = c(ORCID = "0000-0002-8319-7624"),
        role = c("cre", "aut")),
    person(
        given = "Ian R.", 
        family = "White", 
        role = "aut"))
Description: Summarise results from simulation studies and compute Monte
    Carlo standard errors of commonly used summary statistics. This
    package is modelled on the 'simsum' user-written command in 'Stata'
    (White I.R., 2010
    <https://www.stata-journal.com/article.html?article=st0200>), further
    extending it with additional performance measures and functionality.
License: GPL (>= 3)
URL: https://ellessenne.github.io/rsimsum/,
        https://github.com/ellessenne/rsimsum
BugReports: https://github.com/ellessenne/rsimsum/issues
Depends: R (>= 2.10)
Imports: checkmate, generics, ggplot2, ggridges, knitr, lifecycle,
        rlang (>= 1.2.0), scales, stats
Suggests: covr, devtools, dplyr, eha, rmarkdown, rstpm2, survival,
        testthat, usethis
VignetteBuilder: knitr
ByteCompile: true
Encoding: UTF-8
Language: en-GB
LazyData: true
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-21 17:39:21 UTC; ellessenne
Author: Alessandro Gasparini [cre, aut] (ORCID:
    <https://orcid.org/0000-0002-8319-7624>),
  Ian R. White [aut]
Maintainer: Alessandro Gasparini <alessandro@ellessenne.xyz>
Repository: CRAN
Date/Publication: 2026-04-21 18:12:23 UTC
Built: R 4.6.0; ; 2026-04-26 14:55:28 UTC; unix
