# Generated by roxygen2: do not edit by hand

S3method(autoplot,multisimsum)
S3method(autoplot,simsum)
S3method(autoplot,summary.multisimsum)
S3method(autoplot,summary.simsum)
S3method(kable,multisimsum)
S3method(kable,simsum)
S3method(kable,summary.multisimsum)
S3method(kable,summary.simsum)
S3method(print,multisimsum)
S3method(print,simsum)
S3method(print,summary.multisimsum)
S3method(print,summary.simsum)
S3method(summary,multisimsum)
S3method(summary,simsum)
S3method(tidy,multisimsum)
S3method(tidy,simsum)
S3method(tidy,summary.multisimsum)
S3method(tidy,summary.simsum)
export(dropbig)
export(get_data)
export(is.multisimsum)
export(is.simsum)
export(is.summary.multisimsum)
export(is.summary.simsum)
export(kable)
export(multisimsum)
export(nsim)
export(simsum)
export(tidy)
import(generics)
import(ggplot2)
import(knitr)
import(rlang)
import(scales)
import(stats)
importFrom(checkmate,assert_character)
importFrom(checkmate,assert_int)
importFrom(checkmate,assert_list)
importFrom(checkmate,assert_logical)
importFrom(checkmate,assert_number)
importFrom(checkmate,assert_string)
importFrom(checkmate,assert_subset)
importFrom(checkmate,assert_true)
importFrom(checkmate,makeAssertCollection)
importFrom(checkmate,reportAssertions)
importFrom(generics,tidy)
importFrom(ggridges,geom_density_ridges)
importFrom(lifecycle,deprecate_warn)
