% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/print.multisimsum.R
\name{print.multisimsum}
\alias{print.multisimsum}
\title{print.multisimsum}
\usage{
\method{print}{multisimsum}(x, ...)
}
\arguments{
\item{x}{An object of class \code{multisimsum}.}

\item{...}{Ignored.}
}
\description{
Print method for multisimsum objects
}
\examples{
data(frailty)
ms <- multisimsum(
  data = frailty, par = "par", true = c(
    trt = -0.50,
    fv = 0.75
  ), estvarname = "b", se = "se", methodvar = "model",
  by = "fv_dist"
)
ms

data("frailty", package = "rsimsum")
frailty$true <- ifelse(frailty$par == "trt", -0.50, 0.75)
ms <- multisimsum(data = frailty, par = "par", estvarname = "b", true = "true")
ms
}
