% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/is.R
\name{is.summary.simsum}
\alias{is.summary.simsum}
\title{is.summary.simsum}
\usage{
is.summary.simsum(x)
}
\arguments{
\item{x}{An object to test.}
}
\description{
Reports whether x is a summary.simsum object
}
